@@ -68,7 +68,7 @@ class Work:
 
         def getter(work):
             if work.list_price:
-                return work.list_price * Decimal(str(work.total_effort))
+                return work.list_price * Decimal(str(work.effort))
             else:
                 return Decimal(0)
 
